---
title: <span class="badge object-type-scalar"></span> Megabytes
---
# <span class="badge object-type-scalar"></span> Megabytes

Data: megabytes

## Definition

```python
# Data: megabytes
Megabytes: typing.Literal["decmbytes"] = "decmbytes"
```
